@@ -1,6 +1,6 @@
 #[derive(Debug, Clone, PartialEq, Eq, Hash)]
 pub struct Event {
-    pub typ: String,
+    pub event: String,
     pub data: String,
     pub last_event_id: Option<String>,
 }
